summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/libgroupwise/tasks/getstatustask.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /kopete/protocols/groupwise/libgroupwise/tasks/getstatustask.cpp
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/groupwise/libgroupwise/tasks/getstatustask.cpp')
-rw-r--r--kopete/protocols/groupwise/libgroupwise/tasks/getstatustask.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/groupwise/libgroupwise/tasks/getstatustask.cpp b/kopete/protocols/groupwise/libgroupwise/tasks/getstatustask.cpp
index dde055a6..153746ea 100644
--- a/kopete/protocols/groupwise/libgroupwise/tasks/getstatustask.cpp
+++ b/kopete/protocols/groupwise/libgroupwise/tasks/getstatustask.cpp
@@ -30,7 +30,7 @@ GetStatusTask::~GetStatusTask()
{
}
-void GetStatusTask::userDN( const QString & dn )
+void GetStatusTask::userDN( const TQString & dn )
{
m_userDN = dn;
// set up Transfer
@@ -60,8 +60,8 @@ bool GetStatusTask::take( Transfer * transfer )
// This must be because the sender is not on our contact list but has sent us a message.
// TODO: Check that the change to sending DNs above has fixed this problem.
status = sf->value().toInt();
- // unfortunately getstatus doesn't give us an away message so we pass QString::null here
- emit gotStatus( m_userDN, status, QString::null );
+ // unfortunately getstatus doesn't give us an away message so we pass TQString::null here
+ emit gotStatus( m_userDN, status, TQString::null );
setSuccess();
}
else